@@ -1,30 +1,26 @@
 package Dancer2::Plugin::REST;
-BEGIN {
-  $Dancer2::Plugin::REST::AUTHORITY = 'cpan:SUKRIA';
-}
-# ABSTRACT: A plugin for writing RESTful apps with Dancer2
-$Dancer2::Plugin::REST::VERSION = '0.23_00';
 use strict;
 use warnings;
 
 use Carp 'croak';
-
-use Dancer2 0.149000_01;
+use Dancer2 ':syntax';
 use Dancer2::Plugin;
-use Class::Load qw/ try_load_class /;
 
-use Moo::Role;
+our $AUTHORITY = 'SUKRIA';
+our $VERSION   = '0.08';
+
+use Moo;
 
 with 'Dancer2::Plugin';
 
-# [todo] - add XML support
 my $content_types = {
     json => 'application/json',
     yml  => 'text/x-yaml',
+    xml  => 'application/xml',
 };
 
 register prepare_serializer_for_format => sub {
-    my $dsl = shift;
+    my $app = shift;
 
     my $conf        = plugin_setting;
     my $serializers = (
@@ -32,36 +28,29 @@ register prepare_serializer_for_format => sub {
         ? $conf->{serializers}
         : { 'json' => 'JSON',
             'yml'  => 'YAML',
+            'xml'  => 'XML',
             'dump' => 'Dumper',
         }
     );
 
-    $dsl->hook(
-        'before' => sub {
-            my $format = $dsl->params->{'format'};
-            $format  ||= $dsl->captures->{'format'} if $dsl->captures;
-            return unless defined $format;
+    hook 'before' => sub {
+        my $format = params->{'format'};
+        return unless defined $format;
 
-            my $serializer = $serializers->{$format};
-            
-            unless( $serializer ) {
-                return $dsl->send_error("unsupported format requested: " . $format, 404);
-            }
+        my $serializer = $serializers->{$format};
 
-            $dsl->set(serializer => $serializer);
-            $dsl->app->set_response( Dancer2::Core::Response->new(
-                %{ $dsl->app->response },
-                serializer => $dsl->set('serializer'),
-            ) );
-
-            my $ct = $content_types->{$format} || $dsl->setting('content_type');
-            $dsl->content_type($ct);
+        unless( $serializer ) {
+            return send_error "unsupported format requested: " . $format, 404;
         }
-    );
+
+        set serializer => $serializer;
+        my $ct = $content_types->{$format} || setting('content_type');
+        content_type $ct;
+    };
 };
 
 register resource => sub {
-    my $dsl = shift;
+    my $self = shift;
 
     my ($resource, %triggers) = @_;
 
@@ -77,7 +66,7 @@ register resource => sub {
              and grep { $triggers{$_} } keys %actions;
 
     while( my( $action, $code ) = each %triggers ) {
-            $dsl->app->add_route( 
+            $self->app->add_route( 
                 method => $actions{$action},
                 regexp => $_,
                 code   => $code,
@@ -87,11 +76,11 @@ register resource => sub {
 };
 
 register send_entity => sub {
-    my ($dsl, $entity, $http_code) = @_;
+    my ($entity, $http_code) = @_;
 
     $http_code ||= 200;
 
-    $dsl->status($http_code);
+    status($http_code);
     $entity;
 };
 
@@ -168,16 +157,16 @@ for my $code (keys %http_codes) {
     $helper_name = "status_${helper_name}";
 
     register $helper_name => sub {
-        my $dsl = shift;
+        shift;
 
-        $dsl->send_entity(
+        send_entity(
             ( $code >= 400 ? {error => $_[0]} : $_[0] ),
             $code
         );
     };
 }
 
-register_plugin for_versions => [2];
+register_plugin for_versions => [1,2];
 
 1;
 
@@ -185,20 +174,10 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Dancer2::Plugin::REST - A plugin for writing RESTful apps with Dancer2
 
-=head1 VERSION
-
-version 0.23_00
-
-=head1 DESCRIPTION
-
-This plugin helps you write a RESTful webservice with Dancer2.
-
 =head1 SYNOPSYS
 
     package MyWebService;
@@ -212,10 +191,6 @@ This plugin helps you write a RESTful webservice with Dancer2.
         User->find(params->{id});
     };
 
-    get qr{^/user/(?<id>\d+)\.(?<format>\w+)} => sub {
-        User->find(captures->{id});
-    };
-
     # curl http://mywebservice/user/42.json
     { "id": 42, "name": "John Foo", email: "john.foo@example.com"}
 
@@ -225,18 +200,9 @@ This plugin helps you write a RESTful webservice with Dancer2.
     name: "John Foo"
     email: "john.foo@example.com"
 
-=head1 CONFIGURATION
+=head1 DESCRIPTION
 
-=head2 serializers
-
-The default format serializer hash which maps a given C<:format> to 
-a C<Dancer2::Serializer::*> serializer. Unless overriden in the 
-configuration, it defaults to:
-
-    serializers:
-      json: JSON
-      yml:  YAML
-      dump: Dumper
+This plugin helps you write a RESTful webservice with Dancer2.
 
 =head1 KEYWORDS
 
@@ -245,15 +211,12 @@ configuration, it defaults to:
 When this pragma is used, a before filter is set by the plugin to automatically
 change the serializer when a format is detected in the URI.
 
-That means that each route you define with a B<:format> param or captures token 
-will trigger a serializer definition, if the format is known.
+That means that each route you define with a B<:format> token will trigger a
+serializer definition, if the format is known.
 
 This lets you define all the REST actions you like as regular Dancer2 route
 handlers, without explicitly handling the outgoing data format.
 
-Regexp routes will use the file-extension from captures->{'format'} to determine
-the serialization format.
-
 =head2 resource
 
 This keyword lets you declare a resource your application will handle.
@@ -321,15 +284,4 @@ Cuny.
 
 L<Dancer2> L<http://en.wikipedia.org/wiki/Representational_State_Transfer>
 
-=head1 AUTHOR
-
-Dancer Core Developers
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Alexis Sukrieh.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
